@@ -2,18 +2,11 @@
 $LOAD_PATH.unshift File.expand_path('../../lib', __FILE__)
 
 begin
-  if RUBY_VERSION >= '2.0'
-    require 'byebug'
-  elsif RUBY_VERSION >= '1.9'
-    require 'debugger'
-  else
-    require 'ruby-debug'
-  end
+  require 'byebug'
 rescue LoadError
 end
 
 require 'mail'
-require 'mail/parsers'
 
 if ENV['MBCHARS'] == 'activesupport'
   require 'active_support'
