@@ -15,10 +15,6 @@ describe Mail::CcField do
       expect { Mail::CcField.new("Mikel") }.not_to raise_error
     end
 
-    it "should mix in the CommonAddress module" do
-      expect(Mail::CcField.included_modules).to include(Mail::CommonAddress)
-    end
-
     it "should accept a string without the field name" do
       t = Mail::CcField.new('Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
       expect(t.name).to eq 'Cc'
@@ -26,8 +22,6 @@ describe Mail::CcField do
     end
 
   end
-  
-  # Actual testing of CommonAddress methods occurs in the address field spec file
 
   describe "instance methods" do
     it "should return an address" do
