@@ -13,10 +13,6 @@ describe Mail::FromField do
       expect { Mail::FromField.new("Mikel") }.not_to raise_error
     end
 
-    it "should mix in the CommonAddress module" do
-      expect(Mail::FromField.included_modules).to include(Mail::CommonAddress)
-    end
-
     it "should accept a string without the field name" do
       t = Mail::FromField.new('Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
       expect(t.name).to eq 'From'
@@ -25,8 +21,6 @@ describe Mail::FromField do
 
   end
 
-  # Actual testing of CommonAddress methods oFromurs in the address field spec file
-
   describe "instance methods" do
     it "should return an address" do
       t = Mail::FromField.new('Mikel Lindsaar <mikel@test.lindsaar.net>')
