@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 # 
 # resent-to       =       "Resent-To:" address-list CRLF
@@ -8,17 +9,7 @@ describe Mail::ResentToField do
   describe "initialization" do
 
     it "should initialize" do
-      expect { Mail::ResentToField.new("Resent-To: Mikel") }.not_to raise_error
-    end
-
-    it "should mix in the CommonAddress module" do
-      expect(Mail::ResentToField.included_modules).to include(Mail::CommonAddress) 
-    end
-
-    it "should accept a string with the field name" do
-      t = Mail::ResentToField.new('Resent-To: Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>')
-      expect(t.name).to eq 'Resent-To'
-      expect(t.value).to eq 'Mikel Lindsaar <mikel@test.lindsaar.net>, "Bob Smith" <bob@me.com>'
+      expect { Mail::ResentToField.new("Mikel") }.not_to raise_error
     end
 
     it "should accept a string without the field name" do
@@ -28,8 +19,6 @@ describe Mail::ResentToField do
     end
 
   end
-  
-  # Actual testing of CommonAddress methods oResentTours in the address field spec file
 
   describe "instance methods" do
     it "should return an address" do
