@@ -66,11 +66,9 @@ describe Mail::Message do
       expect(mail.from).to eq ['mikel@me.com']
       expect(mail.to).to eq ['lindsaar@you.com']
 
-      if RUBY_VERSION >= '1.9'
-        mail = ClassThatCreatesMail.new('mikel@me.com', 'lindsaar@you.com').create_mail_with_splat_args
-        expect(mail.from).to eq ['mikel@me.com']
-        expect(mail.to).to eq ['lindsaar@you.com']
-      end
+      mail = ClassThatCreatesMail.new('mikel@me.com', 'lindsaar@you.com').create_mail_with_splat_args
+      expect(mail.from).to eq ['mikel@me.com']
+      expect(mail.to).to eq ['lindsaar@you.com']
     end
 
     it "should initialize a body and header class even if called with nothing to begin with" do
@@ -122,24 +120,11 @@ describe Mail::Message do
       read_fixture('emails', 'error_emails', 'must_supply_encoding.eml')
     end
 
-    it "should be able to parse every email example we have without raising an exception" do
-      emails = Dir.glob( fixture_path('emails/**/*') ).delete_if { |f| File.directory?(f) }
-
-      allow(Kernel).to receive(:warn) # Don't want to get noisy about any warnings
-      errors = false
-      expected_failures = []
-      emails.each do |email|
-        begin
-          Mail.read(email)
-        rescue => e
-          unless expected_failures.include?(email)
-            puts "Failed on email #{email}"
-            puts "Failure was:\n#{e}\n\n"
-            errors = true
-          end
-        end
+    Dir.glob(fixture_path('emails/**/*.eml')).each do |path|
+      it "parses #{path} fixture" do
+        allow(Kernel).to receive(:warn) # Don't want to get noisy about any warnings
+        expect { Mail.read(path) }.to_not raise_error
       end
-      expect(errors).to be_falsey
     end
 
     it "should be able to parse a large email without raising an exception" do
@@ -152,8 +137,9 @@ describe Mail::Message do
     end
 
     it "should not raise a warning on having non US-ASCII characters in the header (should just handle it)" do
-      expect($stderr).not_to receive(:puts)
-      read_fixture('emails', 'plain_emails', 'raw_email_string_in_date_field.eml')
+      expect {
+        read_fixture('emails', 'plain_emails', 'raw_email_string_in_date_field.eml')
+      }.to_not output.to_stderr
     end
 
     it "should raise a warning (and keep parsing) on having an incorrectly formatted header" do
@@ -178,6 +164,16 @@ describe Mail::Message do
       expect(Mail::Utilities.blank?(mail.in_reply_to)).to be_truthy
     end
 
+    it "should be able to pass two In-Reply-To headers" do
+      mail = Mail.new("From: bob\r\nIn-Reply-To: <a@a.a>\r\nIn-Reply-To: <b@b.b>\r\nSubject: Hello!\r\n\r\nemail message\r\n")
+      expect(mail.in_reply_to).to eq 'b@b.b'
+    end
+
+    it "should be able to pass two References headers" do
+      mail = Mail.new("From: bob\r\nReferences: <a@a.a>\r\nReferences: <b@b.b>\r\nSubject: Hello!\r\n\r\nemail message\r\n")
+      expect(mail.references).to eq 'b@b.b'
+    end
+
     describe "YAML serialization" do
       before(:each) do
         # Ensure specs don't randomly fail due to messages being generated 1 second apart
@@ -198,7 +194,7 @@ describe Mail::Message do
 
       it "should serialize the basic information to YAML" do
         yaml = @yaml_mail.to_yaml
-        yaml_output = YAML.load(yaml)
+        yaml_output = Mail::YAML.load(yaml)
         expect(yaml_output['headers']['To']).to       eq "someone@somewhere.com"
         expect(yaml_output['headers']['Cc']).to       eq "someoneelse@somewhere.com"
         expect(yaml_output['headers']['Subject']).to  eq "subject"
@@ -216,7 +212,7 @@ describe Mail::Message do
       it "should serialize a Message with a custom delivery_handler" do
         @yaml_mail.delivery_handler = DeliveryAgent
         yaml = @yaml_mail.to_yaml
-        yaml_output = YAML.load(yaml)
+        yaml_output = Mail::YAML.load(yaml)
         expect(yaml_output['delivery_handler']).to eq "DeliveryAgent"
       end
 
@@ -228,12 +224,19 @@ describe Mail::Message do
 
       it "should not deserialize a delivery_handler that does not exist" do
         yaml = @yaml_mail.to_yaml
-        yaml_hash = YAML.load(yaml)
+        yaml_hash = Mail::YAML.load(yaml)
         yaml_hash['delivery_handler'] = "NotARealClass"
         deserialized = Mail::Message.from_yaml(yaml_hash.to_yaml)
         expect(deserialized.delivery_handler).to be_nil
       end
 
+      it "should deserialize parts as an instance of Mail::PartsList" do
+        yaml = @yaml_mail.to_yaml
+        yaml_hash = Mail::YAML.load(yaml)
+        deserialized = Mail::Message.from_yaml(yaml_hash.to_yaml)
+        expect(deserialized.parts).to be_kind_of(Mail::PartsList)
+      end
+
       it "should handle multipart mail" do
         @yaml_mail.add_part Mail::Part.new(:content_type => 'text/html', :body => '<b>body</b>')
         deserialized = Mail::Message.from_yaml(@yaml_mail.to_yaml)
@@ -544,7 +547,7 @@ describe Mail::Message do
 
       it "should allow you to replace a from field" do
         mail = Mail.new
-        expect(mail.from).to eq nil
+        expect(mail.from).to be_nil
         mail.from = 'mikel@test.lindsaar.net'
         expect(mail.from).to eq ['mikel@test.lindsaar.net']
         mail.from = 'bob@test.lindsaar.net'
@@ -978,33 +981,33 @@ describe Mail::Message do
 
   describe "making a copy of a message with dup" do
     def message_should_have_default_values(message)
-      expect(message.bcc).to           eq nil
-      expect(message.cc).to            eq nil
-      expect(message.comments).to      eq nil
-      expect(message.date).to          eq nil
-      expect(message.from).to          eq nil
-      expect(message.in_reply_to).to   eq nil
-      expect(message.keywords).to      eq nil
-      expect(message.message_id).to    eq nil
-      expect(message.received).to      eq nil
-      expect(message.references).to    eq nil
-      expect(message.reply_to).to      eq nil
-      expect(message.resent_bcc).to    eq nil
-      expect(message.resent_cc).to     eq nil
-      expect(message.resent_date).to   eq nil
-      expect(message.resent_from).to   eq nil
-      expect(message.resent_message_id).to eq nil
-      expect(message.resent_sender).to eq nil
-      expect(message.resent_to).to     eq nil
-      expect(message.sender).to        eq nil
-      expect(message.subject).to       eq nil
-      expect(message.to).to            eq nil
-      expect(message.content_type).to              eq nil
-      expect(message.content_transfer_encoding).to eq nil
-      expect(message.content_description).to       eq nil
-      expect(message.content_disposition).to       eq nil
-      expect(message.content_id).to                eq nil
-      expect(message.mime_version).to              eq nil
+      expect(message.bcc).to           be_nil
+      expect(message.cc).to            be_nil
+      expect(message.comments).to      be_nil
+      expect(message.date).to          be_nil
+      expect(message.from).to          be_nil
+      expect(message.in_reply_to).to   be_nil
+      expect(message.keywords).to      be_nil
+      expect(message.message_id).to    be_nil
+      expect(message.received).to      be_nil
+      expect(message.references).to    be_nil
+      expect(message.reply_to).to      be_nil
+      expect(message.resent_bcc).to    be_nil
+      expect(message.resent_cc).to     be_nil
+      expect(message.resent_date).to   be_nil
+      expect(message.resent_from).to   be_nil
+      expect(message.resent_message_id).to be_nil
+      expect(message.resent_sender).to be_nil
+      expect(message.resent_to).to     be_nil
+      expect(message.sender).to        be_nil
+      expect(message.subject).to       be_nil
+      expect(message.to).to            be_nil
+      expect(message.content_type).to              be_nil
+      expect(message.content_transfer_encoding).to be_nil
+      expect(message.content_description).to       be_nil
+      expect(message.content_disposition).to       be_nil
+      expect(message.content_id).to                be_nil
+      expect(message.mime_version).to              be_nil
       expect(message.body.to_s).to          eq ''
     end
 
@@ -1318,8 +1321,7 @@ describe Mail::Message do
           body = "This is plain text US-ASCII"
           mail = Mail.new
           mail.body = body
-          expect($stderr).not_to receive(:puts)
-          mail.to_s
+          expect { mail.to_s }.to_not output.to_stderr
         end
 
         it "should set the content type to text/plain; charset=us-ascii" do
@@ -1350,8 +1352,12 @@ describe Mail::Message do
           mail = Mail.new
           mail.body = body
           mail.content_transfer_encoding = "8bit"
-          expect($stderr).to receive(:puts).with(/Non US-ASCII detected and no charset defined.\nDefaulting to UTF-8, set your own if this is incorrect./m)
-          expect(mail.to_s).to match(%r{|Content-Type: text/plain; charset=UTF-8|})
+
+          result = nil
+          expect {
+            result = mail.to_s
+          }.to output(/Non US-ASCII detected and no charset defined.\nDefaulting to UTF-8, set your own if this is incorrect./).to_stderr
+          expect(result).to match(%r{|Content-Type: text/plain; charset=UTF-8|})
         end
 
         it "should raise a warning if there is no charset parameter and there is non ascii chars and default to text/plain, UTF-8" do
@@ -1360,8 +1366,12 @@ describe Mail::Message do
           mail.body = body
           mail.content_type = "text/plain"
           mail.content_transfer_encoding = "8bit"
-          expect($stderr).to receive(:puts).with(/Non US-ASCII detected and no charset defined.\nDefaulting to UTF-8, set your own if this is incorrect./m)
-          expect(mail.to_s).to match(%r{|Content-Type: text/plain; charset=UTF-8|})
+
+          result = nil
+          expect {
+            result = mail.to_s
+          }.to output(/Non US-ASCII detected and no charset defined.\nDefaulting to UTF-8, set your own if this is incorrect./).to_stderr
+          expect(result).to match(%r{|Content-Type: text/plain; charset=UTF-8|})
         end
 
         it "should not raise a warning if there is no charset parameter and the content-type is not text" do
@@ -1370,8 +1380,7 @@ describe Mail::Message do
           mail.body = body
           mail.content_type = "image/png"
           mail.content_transfer_encoding = "8bit"
-          expect($stderr).to_not receive(:puts)
-          mail.to_s
+          expect { mail.to_s }.to_not output.to_stderr
         end
 
         it "should not raise a warning if there is a charset defined and there is non ascii chars" do
@@ -1380,8 +1389,7 @@ describe Mail::Message do
           mail.body = body
           mail.content_transfer_encoding = "8bit"
           mail.content_type = "text/plain; charset=UTF-8"
-          expect($stderr).not_to receive(:puts)
-          mail.to_s
+          expect { mail.to_s }.to_not output.to_stderr
         end
 
         it "should be able to set a content type with an array and hash" do
@@ -1440,6 +1448,65 @@ describe Mail::Message do
         expect(mail.parts.last.content_transfer_encoding).to match(/7bit|8bit|binary/)
       end
 
+      describe 'charset' do
+        it 'should return a default value for multipart mails' do
+          mail = Mail.new
+          mail.add_part(Mail::Part.new(body: 'PLAIN TEXT', content_type: 'text/plain'))
+          expect(mail.charset).to eq 'UTF-8'
+        end
+      end
+
+      describe 'charset=' do
+        before do
+          @mail = Mail.new do
+            to 'mikel@test.lindsaar.net'
+            from 'bob@test.lindsaar.net'
+            subject 'Multipart email'
+            text_part do
+              body 'This is plain text'
+            end
+            html_part do
+              content_type 'text/html; charset=UTF-8'
+              body '<h1>This is HTML</h1>'
+            end
+          end
+        end
+        
+        it "should not add an empty charset header" do
+          @mail.charset = nil
+          
+          expect(@mail.multipart?).to eq true
+          expect(@mail.parts.count).to eq 2
+          expect(@mail.encoded.scan(/charset=UTF-8/).count).to eq 2
+        end
+        
+        it "should remove the charset header" do
+          @mail.charset = 'iso-8859-1'
+          @mail.charset = nil
+          
+          expect(@mail.encoded.scan(/charset=UTF-8/).count).to eq 2
+          expect(@mail.encoded.scan(/charset=iso-8859-1/).count).to eq 0
+        end
+      end
+
+      describe "convert_to_multipart" do
+        subject do
+          read_fixture('emails', 'attachment_emails', 'attachment_only_email.eml').tap(&:convert_to_multipart)
+        end
+
+        it "original content headers move to the new part" do
+          expect(subject.header[:content_type]).to be_nil
+          expect(subject.header[:content_disposition]).to be_nil
+          expect(subject.header[:content_description]).to be_nil
+          expect(subject.header[:content_transfer_encoding]).to be_nil
+
+          expect(subject.parts[0].header[:content_type].value).to eq("application/x-gzip; NAME=blah.gz")
+          expect(subject.parts[0].header[:content_disposition].value).to eq("attachment; filename=blah.gz")
+          expect(subject.parts[0].header[:content_description].value).to eq("Attachment has identical content to above foo.gz")
+          expect(subject.parts[0].header[:content_transfer_encoding].value).to eq("base64")
+        end
+      end
+
       describe "content-transfer-encoding" do
 
         it "should use 7bit for only US-ASCII chars" do
@@ -1465,6 +1532,23 @@ describe Mail::Message do
           expect(mail.to_s).to match(%r{Content-Transfer-Encoding: quoted-printable})
         end
 
+        it "should use QP transfer encoding for 8bit text attachment with only a few 8bit characters" do
+          mail = Mail.new
+          file_content = String.new("Pok\xE9mon")
+          file_content = file_content.force_encoding('BINARY') if file_content.respond_to?(:force_encoding)
+          mail.attachments['iso_text.txt'] = file_content
+          mail.body = 'This is plain text US-ASCII'
+          expect(mail.to_s).to match(%r{
+            Content-Transfer-Encoding:\ 7bit
+            .*
+            This\ is\ plain\ text\ US-ASCII
+            .*
+            Content-Transfer-Encoding:\ quoted-printable
+            .*
+            Pok=E9mon
+          }mx)
+        end
+
         it "should use base64 transfer encoding for 8-bit text with lots of 8bit characters" do
           body = "This is NOT plain text ASCII　− かきくけこ"
           mail = Mail.new
@@ -1476,7 +1560,7 @@ describe Mail::Message do
           expect(mail.to_s).to match(%r{Content-Transfer-Encoding: base64})
         end
 
-        it "should not use 8bit transfer encoding when 8bit is allowed" do
+        it "should use 8bit transfer encoding when 8bit is forced" do
           body = "This is NOT plain text ASCII　− かきくけこ"
           mail = Mail.new
           mail.charset = "UTF-8"
@@ -1549,7 +1633,7 @@ describe Mail::Message do
           body "The=3Dbody"
         end
         expect(mail.body.decoded).to eq "The=body"
-        expect(mail.body.encoded).to eq "The=3Dbody=\n"
+        expect(mail.body.encoded).to eq "The=3Dbody=\r\n"
       end
 
       it "should change a body on decode if given an encoding type to decode" do
@@ -1580,10 +1664,10 @@ describe Mail::Message do
     end
 
     def with_encoder(encoder)
-      old, Mail::Ruby19.charset_encoder = Mail::Ruby19.charset_encoder, encoder
+      old, Mail::Utilities.charset_encoder = Mail::Utilities.charset_encoder, encoder
       yield
     ensure
-      Mail::Ruby19.charset_encoder = old
+      Mail::Utilities.charset_encoder = old
     end
 
     let(:message){
@@ -1598,12 +1682,14 @@ describe Mail::Message do
       expect(message.text?).to eq true
     end
 
-    if RUBY_VERSION > "1.9"
-      it "uses the Ruby19 charset encoder" do
-        with_encoder(Mail::Ruby19::BestEffortCharsetEncoder.new) do
-          message = Mail.new("Content-Type: text/plain;\r\n charset=windows-1258\r\nContent-Transfer-Encoding: base64\r\n\r\nSGkglg==\r\n")
-          expect(message.decoded).to eq("Hi –")
-        end
+    it "inspect_structure should return the same as inspect (no attachments)" do
+      expect(message.inspect_structure).to eq message.inspect
+    end
+
+    it "uses the Utilities charset encoder" do
+      with_encoder(Mail::Utilities::BestEffortCharsetEncoder.new) do
+        message = Mail.new("Content-Type: text/plain;\r\n charset=windows-1258\r\nContent-Transfer-Encoding: base64\r\n\r\nSGkglg==\r\n")
+        expect(message.decoded).to eq("Hi –")
       end
     end
   end
@@ -1633,19 +1719,23 @@ describe Mail::Message do
       it "should ignore the message id value if self has a nil message id" do
         m1 = Mail.new("To: mikel@test.lindsaar.net\r\nSubject: Yo!\r\n\r\nHello there")
         m2 = Mail.new("To: mikel@test.lindsaar.net\r\nMessage-ID: <1234@test.lindsaar.net>\r\nSubject: Yo!\r\n\r\nHello there")
-        expect(m1).to eq m2
+
         # confirm there are no side-effects in the comparison
         expect(m1[:message_id]).to be_nil
         expect(m2[:message_id].value).to eq '<1234@test.lindsaar.net>'
+
+        expect(m1).to eq m2
       end
 
       it "should ignore the message id value if other has a nil message id" do
         m1 = Mail.new("To: mikel@test.lindsaar.net\r\nMessage-ID: <1234@test.lindsaar.net>\r\nSubject: Yo!\r\n\r\nHello there")
         m2 = Mail.new("To: mikel@test.lindsaar.net\r\nSubject: Yo!\r\n\r\nHello there")
-        expect(m1).to eq m2
+
         # confirm there are no side-effects in the comparison
         expect(m1[:message_id].value).to eq '<1234@test.lindsaar.net>'
         expect(m2[:message_id]).to be_nil
+
+        expect(m1).to eq m2
       end
 
       it "should not be == if both emails have different Message IDs" do
@@ -1907,6 +1997,24 @@ describe Mail::Message do
     end
   end
 
+  describe "adding parts should preserve the charset of the mail" do
+    charsets = ['UTF-8', 'ISO-8859-1', nil]
+    charsets.each do |mail_charset|
+      charsets.each do |part_charset|
+        it "when #{mail_charset || 'nil'} vs #{part_charset || 'nil'}" do
+          mail = Mail.new
+          mail['charset'] = mail_charset
+          expect(mail.charset).to eq mail_charset
+          p = Mail::Part.new(:content_type => 'text/html', :body => 'HTML TEXT', :charset => part_charset)
+          expect(p.charset).to eq part_charset
+          mail.add_part(p)
+          expect(mail.charset).to eq mail_charset
+          expect(p.charset).to eq part_charset
+        end
+      end
+    end
+  end
+
   describe "ordering messages" do
     it "should put all attachments as the last item" do
       mail = Mail.new
@@ -1954,16 +2062,21 @@ describe Mail::Message do
 
   describe "without_attachments!" do
     it "should delete all attachments" do
-      emails_with_attachments = ['content_disposition', 'content_location',
-                                 'pdf', 'with_encoded_name', 'with_quoted_filename']
+      emails_with_attachments = [
+        ['attachment_emails', 'attachment_content_disposition.eml'],
+        ['attachment_emails', 'attachment_content_location.eml'],
+        ['attachment_emails', 'attachment_pdf.eml'],
+        ['attachment_emails', 'attachment_with_encoded_name.eml'],
+        ['attachment_emails', 'attachment_with_quoted_filename.eml'],
+        ['mime_emails', 'raw_email7.eml']]
 
-      emails_with_attachments.each { |email|
-        mail = read_fixture('emails', 'attachment_emails', "attachment_#{email}.eml")
-        non_attachment_parts = mail.parts.reject(&:attachment?)
+      emails_with_attachments.each { |file_name|
+        mail = read_fixture('emails', *file_name)
+        non_attachment_parts = mail.all_parts.reject(&:attachment?)
         expect(mail.has_attachments?).to be_truthy
         mail.without_attachments!
 
-        expect(mail.parts).to eq non_attachment_parts
+        expect(mail.all_parts).to eq non_attachment_parts
         expect(mail.has_attachments?).to be_falsey
       }
     end
@@ -1989,8 +2102,8 @@ describe Mail::Message do
         expect(@mail.reply.references).to eq '6B7EC235-5B17-4CA8-B2B8-39290DEB43A3@test.lindsaar.net'
       end
 
-      it "should RE: the original subject" do
-        expect(@mail.reply.subject).to eq 'RE: Testing 123'
+      it "should Re: the original subject" do
+        expect(@mail.reply.subject).to eq 'Re: Testing 123'
       end
 
       it "should be sent to the original sender" do
@@ -2051,7 +2164,7 @@ describe Mail::Message do
         expect(@mail.reply[:references].message_ids).to eq ['473FF3B8.9020707@xxx.org', '348F04F142D69C21-291E56D292BC@xxxx.net', '473FFE27.20003@xxx.org']
       end
 
-      it "should not append another RE:" do
+      it "should not append another Re:" do
         expect(@mail.reply.subject).to eq "Re: Test reply email"
       end
 
