@@ -13,7 +13,7 @@ describe "MIME Emails" do
 
       it "should return nil if the email has no mime version" do
         mail = Mail.new("To: bob")
-        expect(mail.mime_version).to eq nil
+        expect(mail.mime_version).to be_nil
       end
 
       it "should read the content-transfer-encoding" do
@@ -57,9 +57,23 @@ describe "MIME Emails" do
         expect(mail.content_type_parameters).to eql({"charset" => 'US-ASCII', "format" => 'flowed'})
       end
 
-      it "should recognize a multipart email" do
-        mail = read_fixture('emails', 'mime_emails', 'raw_email7.eml')
-        expect(mail).to be_multipart
+      describe 'a multipart email (raw_email7.eml)' do
+        let(:mail) { read_fixture('emails', 'mime_emails', 'raw_email7.eml') }
+        it "should recognize a multipart email" do
+          expect(mail).to be_multipart
+        end
+
+        it "inspect_structure should return what is expected" do
+          expect(mail.inspect_structure).to eq <<-End.chomp
+#{mail.inspect}
+1. #{mail.parts[0].inspect}
+1.1. #{mail.parts[0].parts[0].inspect}
+1.2. #{mail.parts[0].parts[1].inspect}
+1.3. #{mail.parts[0].parts[2].inspect}
+1.4. #{mail.parts[0].parts[3].inspect}
+2. #{mail.parts[1].inspect}
+          End
+        end
       end
 
       it "should recognize a non multipart email" do
@@ -72,9 +86,14 @@ describe "MIME Emails" do
         expect(mail.attachment?).to eq false
       end
 
-      it "should report the email as :attachment?" do
-        mail = read_fixture('emails', 'attachment_emails', 'attachment_only_email.eml')
-        expect(mail.attachment?).to eq true
+      describe 'attachment_only_email.eml' do
+        let(:mail) { read_fixture('emails', 'attachment_emails', 'attachment_only_email.eml') }
+        it "should report the email as :attachment?" do
+          expect(mail.attachment?).to eq true
+        end
+        it "inspect_structure should return what is expected" do
+          expect(mail.inspect_structure).to eq mail.inspect
+        end
       end
 
       it "should recognize an attachment part" do
@@ -89,11 +108,20 @@ describe "MIME Emails" do
         expect(mail.parts.length).to eq 2
       end
 
-      it "should give the content_type of each part" do
-        mail = read_fixture('emails', 'mime_emails', 'raw_email11.eml')
-        expect(mail.mime_type).to eq 'multipart/alternative'
-        expect(mail.parts[0].mime_type).to eq 'text/plain'
-        expect(mail.parts[1].mime_type).to eq 'text/enriched'
+      describe 'a multipart/alternative mail (raw_email11.eml)' do
+        let(:mail) { read_fixture('emails', 'mime_emails', 'raw_email11.eml') }
+        it "should give the content_type of each part" do
+          expect(mail.mime_type).to eq 'multipart/alternative'
+          expect(mail.parts[0].mime_type).to eq 'text/plain'
+          expect(mail.parts[1].mime_type).to eq 'text/enriched'
+        end
+        it "inspect_structure should return what is expected" do
+          expect(mail.inspect_structure).to eq <<-End.chomp
+#{mail.inspect}
+1. #{mail.parts[0].inspect}
+2. #{mail.parts[1].inspect}
+          End
+        end
       end
 
       it "should report the mail :has_attachments?" do
@@ -135,7 +163,7 @@ describe "MIME Emails" do
 
       it "should return nil if there is no content-type defined" do
         mail = Mail.new
-        expect(mail.boundary).to eq nil
+        expect(mail.boundary).to be_nil
       end
 
       it "should assign the text part and allow you to reference" do
@@ -389,9 +417,6 @@ describe "MIME Emails" do
       end
 
       Dir.glob(fixture_path('attachments', "test.*")).each do |test_attachment|
-        # This spec fails for (most?) jpegs in 1.8.7
-        next if test_attachment.end_with?('test.jpg') && RUBY_VERSION < '1.9'
-
         it "should find binary encoded attachments of type #{File.extname(test_attachment)}" do
           pre, post = read_raw_fixture('emails', 'mime_emails', 'raw_email_with_binary_encoded.eml').split('BINARY_CONTENT_GOES_HERE')
           raw_file  = File.open(test_attachment, "rb", &:read)
@@ -498,25 +523,19 @@ describe "MIME Emails" do
           add_file fixture_path('attachments', 'test.pdf')
           add_file fixture_path('attachments', 'test.zip')
         end
-        if RUBY_VERSION >= '1.9'
-          tripped = mail.attachments[0].decoded
-          original = read_raw_fixture('attachments', 'test.png')
-          expect(tripped).to eq original
-          tripped = mail.attachments[1].decoded
-          original = read_raw_fixture('attachments', 'test.jpg')
-          expect(tripped).to eq original
-          tripped = mail.attachments[2].decoded
-          original = read_raw_fixture('attachments', 'test.pdf')
-          expect(tripped).to eq original
-          tripped = mail.attachments[3].decoded
-          original = read_raw_fixture('attachments', 'test.zip')
-          expect(tripped).to eq original
-        else
-          expect(mail.attachments[0].decoded).to eq read_raw_fixture('attachments', 'test.png')
-          expect(mail.attachments[1].decoded).to eq read_raw_fixture('attachments', 'test.jpg')
-          expect(mail.attachments[2].decoded).to eq read_raw_fixture('attachments', 'test.pdf')
-          expect(mail.attachments[3].decoded).to eq read_raw_fixture('attachments', 'test.zip')
-        end
+
+        tripped = mail.attachments[0].decoded
+        original = read_raw_fixture('attachments', 'test.png')
+        expect(tripped).to eq original
+        tripped = mail.attachments[1].decoded
+        original = read_raw_fixture('attachments', 'test.jpg')
+        expect(tripped).to eq original
+        tripped = mail.attachments[2].decoded
+        original = read_raw_fixture('attachments', 'test.pdf')
+        expect(tripped).to eq original
+        tripped = mail.attachments[3].decoded
+        original = read_raw_fixture('attachments', 'test.zip')
+        expect(tripped).to eq original
       end
 
       it "should allow you to send in file data instead of having to read it" do
@@ -527,13 +546,10 @@ describe "MIME Emails" do
           to      'mikel@to.lindsaar.net'
           add_file(:filename => 'test.png', :content => file_data)
         end
-        if RUBY_VERSION >= '1.9'
-          tripped = mail.attachments[0].decoded
-          original = read_raw_fixture('attachments', 'test.png')
-          expect(tripped).to eq original
-        else
-          expect(mail.attachments[0].decoded).to eq read_raw_fixture('attachments', 'test.png')
-        end
+
+        tripped = mail.attachments[0].decoded
+        original = read_raw_fixture('attachments', 'test.png')
+        expect(tripped).to eq original
       end
 
       it "should support :mime_type option" do
@@ -590,8 +606,7 @@ describe "MIME Emails" do
         mail.body = body
         mail.charset = 'UTF-8'
         mail.add_file fixture_path('attachments', 'test.png')
-        expect($stderr).not_to receive(:puts)
-        mail.to_s
+        expect { mail.to_s }.to_not output.to_stderr
       end
 
 
