@@ -5,39 +5,13 @@ require 'spec_helper'
 describe "SMTP Delivery Method" do
 
   before(:each) do
+    MockSMTP.reset
+
     # Reset all defaults back to original state
-    Mail.defaults do
-      delivery_method :smtp, { :address              => "localhost",
-                               :port                 => 25,
-                               :domain               => 'localhost.localdomain',
-                               :user_name            => nil,
-                               :password             => nil,
-                               :authentication       => nil,
-                               :enable_starttls      => nil,
-                               :enable_starttls_auto => true,
-                               :openssl_verify_mode  => nil,
-                               :tls                  => nil,
-                               :ssl                  => nil,
-                               :open_timeout         => nil,
-                               :read_timeout         => nil
-                                }
-    end
-    MockSMTP.clear_deliveries
+    Mail.defaults { delivery_method :smtp, {} }
   end
 
   describe "general usage" do
-    it "dot-stuff unterminated last line of the message" do
-      Mail.deliver do
-        from 'from@example.com'
-        to 'to@example.com'
-        subject 'dot-stuff last line'
-        body "this is a test\n.\nonly a test\n."
-      end
-
-      message = MockSMTP.deliveries.first
-      expect(Mail.new(message).decoded).to eq("this is a test\n..\nonly a test\n..")
-    end
-
     it "should send emails from given settings" do
 
       mail = Mail.deliver do
@@ -219,7 +193,7 @@ describe "SMTP Delivery Method" do
 
       message.deliver!
 
-      expect(MockSMTP.security).to eq :enable_starttls_auto
+      expect(MockSMTP.starttls).to eq :auto
     end
 
     it 'should allow forcing STARTTLS' do
@@ -240,7 +214,70 @@ describe "SMTP Delivery Method" do
 
       message.deliver!
 
-      expect(MockSMTP.security).to eq :enable_starttls
+      expect(MockSMTP.starttls).to eq :always
+    end
+
+    it 'should allow disabling automatic STARTTLS' do
+      message = Mail.new do
+        from 'mikel@test.lindsaar.net'
+        to 'ada@test.lindsaar.net'
+        subject 'Re: No way!'
+        body 'Yeah sure'
+        delivery_method :smtp, { :address         => "localhost",
+                                 :port            => 25,
+                                 :domain          => 'localhost.localdomain',
+                                 :user_name       => nil,
+                                 :password        => nil,
+                                 :authentication  => nil,
+                                 :enable_starttls => false }
+
+      end
+
+      message.deliver!
+
+      expect(MockSMTP.starttls).to eq false
+    end
+
+    it 'should allow forcing STARTTLS auto' do
+      message = Mail.new do
+        from 'mikel@test.lindsaar.net'
+        to 'ada@test.lindsaar.net'
+        subject 'Re: No way!'
+        body 'Yeah sure'
+        delivery_method :smtp, { :address         => "localhost",
+                                 :port            => 25,
+                                 :domain          => 'localhost.localdomain',
+                                 :user_name       => nil,
+                                 :password        => nil,
+                                 :authentication  => nil,
+                                 :enable_starttls_auto => true  }
+
+      end
+
+      message.deliver!
+
+      expect(MockSMTP.starttls).to eq :auto
+    end
+
+    it 'should allow disabling automatic STARTTLS auto' do
+      message = Mail.new do
+        from 'mikel@test.lindsaar.net'
+        to 'ada@test.lindsaar.net'
+        subject 'Re: No way!'
+        body 'Yeah sure'
+        delivery_method :smtp, { :address         => "localhost",
+                                 :port            => 25,
+                                 :domain          => 'localhost.localdomain',
+                                 :user_name       => nil,
+                                 :password        => nil,
+                                 :authentication  => nil,
+                                 :enable_starttls_auto => false }
+
+      end
+
+      message.deliver!
+
+      expect(MockSMTP.starttls).to eq false
     end
   end
 
@@ -274,7 +311,7 @@ describe "SMTP Delivery Method" do
       expect(MockSMTP.deliveries[0][2]).to eq %w(smtp_to@someemail.com)
     end
 
-    it "should not raise errors if there is no envelope From address" do
+    it "should raise an error if there is no envelope From address" do
       mail = Mail.new do
         to "to@somemail.com"
         subject "Email with no sender"
@@ -285,7 +322,7 @@ describe "SMTP Delivery Method" do
 
       expect do
         mail.deliver
-      end.to raise_error('SMTP From address may not be blank: nil')
+      end.to raise_error(ArgumentError, 'SMTP From address may not be blank: nil')
     end
 
     it "should raise an error if no recipient if defined" do
@@ -299,7 +336,7 @@ describe "SMTP Delivery Method" do
 
       expect do
         mail.deliver
-      end.to raise_error('SMTP To address may not be blank: []')
+      end.to raise_error(ArgumentError, 'SMTP To address may not be blank: []')
     end
 
     it "should raise on SMTP injection via MAIL FROM newlines" do
@@ -333,7 +370,7 @@ describe "SMTP Delivery Method" do
     end
 
     it "should raise on SMTP injection via MAIL FROM overflow" do
-      addr = "inject.from@example.com#{'m' * 2025}DATA"
+      addr = "inject.from@example.com#{'m' * 2000}"
 
       mail = Mail.new do
         from addr
@@ -344,11 +381,11 @@ describe "SMTP Delivery Method" do
 
       expect do
         mail.deliver
-      end.to raise_error(ArgumentError, "SMTP From address may not exceed 2kB: #{addr.inspect}")
+      end.to raise_error(ArgumentError, "SMTP From address may not exceed 2000 bytes: #{addr.inspect}")
     end
 
     it "should raise on SMTP injection via RCPT TO overflow" do
-      addr = "inject.to@example.com#{'m' * 2027}DATA"
+      addr = "inject.to@example.com#{'m' * 2000}"
 
       mail = Mail.new do
         from "from@somemail.com"
@@ -359,7 +396,7 @@ describe "SMTP Delivery Method" do
 
       expect do
         mail.deliver
-      end.to raise_error(ArgumentError, "SMTP To address may not exceed 2kB: #{addr.inspect}")
+      end.to raise_error(ArgumentError, "SMTP To address may not exceed 2000 bytes: #{addr.inspect}")
     end
   end
 end
