@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe "Mail::TestMailer" do
@@ -54,30 +55,40 @@ describe "Mail::TestMailer" do
     expect(Mail::TestMailer.deliveries).to be_empty
   end
 
-  it "should raise an error if no sender is defined" do
+  it "should not raise errors if no sender is defined" do
     Mail.defaults do
       delivery_method :test
     end
+
+    mail = Mail.new do
+      to "to@somemail.com"
+      subject "Email with no sender"
+      body "body"
+    end
+
+    expect(mail.smtp_envelope_from).to be_nil
+
     expect do
-      Mail.deliver do
-        to "to@somemail.com"
-        subject "Email with no sender"
-        body "body"
-      end
-    end.to raise_error('An SMTP From address is required to send a message. Set the message smtp_envelope_from, return_path, sender, or from address.')
+      mail.deliver
+    end.to raise_error('SMTP From address may not be blank: nil')
   end
 
   it "should raise an error if no recipient if defined" do
     Mail.defaults do
       delivery_method :test
     end
+
+    mail = Mail.new do
+      from "from@somemail.com"
+      subject "Email with no recipient"
+      body "body"
+    end
+
+    expect(mail.smtp_envelope_to).to eq([])
+
     expect do
-      Mail.deliver do
-        from "from@somemail.com"
-        subject "Email with no recipient"
-        body "body"
-      end
-    end.to raise_error('An SMTP To address is required to send a message. Set the message smtp_envelope_to, to, cc, or bcc address.')
+      mail.deliver
+    end.to raise_error('SMTP To address may not be blank: []')
   end
 
   it "should save settings passed to initialize" do
