@@ -49,8 +49,8 @@ describe "Mail" do
                                                 :openssl_verify_mode  => nil,
                                                 :ssl                  => nil,
                                                 :tls                  => nil,
-                                                :open_timeout         => nil,
-                                                :read_timeout         => nil })
+                                                :open_timeout         => 5,
+                                                :read_timeout         => 5 })
     end
 
     it "should set the retriever method" do
@@ -141,7 +141,8 @@ describe "Mail" do
       tmpdir = File.expand_path('../../../tmp/mail', __FILE__)
       mail.delivery_method :file, :location => tmpdir
       expect(mail.delivery_method.class).to eq Mail::FileDelivery
-      expect(mail.delivery_method.settings).to eql({:location => tmpdir})
+      expect(mail.delivery_method.settings).to eql({:location => tmpdir,
+                                                    :extension => ''})
     end
 
     it "should not change the default when it changes the delivery_method" do
@@ -179,7 +180,7 @@ describe "Mail" do
 
     before(:each) do
       # Set the delivery method to test as the default
-      MockSMTP.clear_deliveries
+      MockSMTP.reset
     end
 
     it "should deliver a mail message" do
