@@ -36,6 +36,12 @@ describe "PartsList" do
     expect(p.sort!(order)).to eq [plain_text_part, html_text_part, no_content_type_part]
   end
 
+  it "should not fail on empty PartsList" do
+    p = Mail::PartsList.new
+    order = ['text/plain']
+    p.sort!(order)
+  end
+
   it "should sort attachments to end" do
     p = Mail::PartsList.new
     order = ['text/plain', 'text/html']
@@ -89,6 +95,6 @@ describe "PartsList" do
 
   it "should have a round-tripping YAML serialization" do
     p = Mail::PartsList.new([1, 2])
-    expect(YAML.load(YAML.dump(p))).to eq(p)
+    expect(Mail::YAML.load(YAML.dump(p))).to eq(p)
   end
 end
