@@ -84,27 +84,25 @@ describe "Utilities Module" do
       expect { quote_phrase(input_str) }.not_to raise_error
     end
 
-    if RUBY_VERSION >= '1.9'
-      describe "given a non-unsafe string" do
-        it "should not change the encoding" do
-          input_str = "blargh"
-          input_str_encoding = input_str.encoding
+    describe "given a non-unsafe string" do
+      it "should not change the encoding" do
+        input_str = "blargh"
+        input_str_encoding = input_str.encoding
 
-          result = quote_phrase(input_str)
+        result = quote_phrase(input_str)
 
-          expect(result.encoding).to eq input_str_encoding
-        end
+        expect(result.encoding).to eq input_str_encoding
       end
+    end
 
-      describe "given an unsafe string" do
-        it "should not change the encoding" do
-          input_str = "Bjørn"
-          input_str_encoding = input_str.encoding
+    describe "given an unsafe string" do
+      it "should not change the encoding" do
+        input_str = "Bjørn"
+        input_str_encoding = input_str.encoding
 
-          result = quote_phrase(input_str)
+        result = quote_phrase(input_str)
 
-          expect(result.encoding).to eq input_str_encoding
-        end
+        expect(result.encoding).to eq input_str_encoding
       end
     end
   end
@@ -382,7 +380,7 @@ describe "Utilities Module" do
   end
 
   describe "url escaping" do
-    uri_parser = URI.const_defined?(:Parser) ? URI::Parser.new : URI
+    uri_parser = Mail::Utilities.uri_parser
 
     it "should have a wrapper on URI.escape" do
       expect(uri_escape("@?@!")).to eq uri_parser.escape("@?@!")
@@ -527,4 +525,11 @@ describe "Utilities Module" do
       end
     end
   end
+
+  describe '.decode_base64' do
+    it "handles unpadded base64 correctly" do
+      decoded = Mail::Utilities.decode_base64("YQ")
+      expect(decoded).to eq "a"
+    end
+  end
 end
